@@ -7,9 +7,8 @@ try:
 except ImportError:
     get_xmlsec_binary = None
 
-
 if get_xmlsec_binary:
-    xmlsec_path = get_xmlsec_binary(["/opt/local/bin","/usr/local/bin"])
+    xmlsec_path = get_xmlsec_binary(["/opt/local/bin", "/usr/local/bin"])
 else:
     xmlsec_path = '/usr/local/bin/xmlsec1'
 
@@ -36,10 +35,13 @@ CONFIG = {
     "key_file": "pki/mykey.pem",
     "cert_file": "pki/mycert.pem",
     "xmlsec_binary": xmlsec_path,
-    #"metadata": {"local": ["../idp2/idp.xml"]},
-    #"metadata": {"local": ["/Users/rolandh/code/so_bridge/idp.xml"]},
-    #"metadata": {"local": ["/Users/rolandh/code/s2sproxy/proxy.xml"]},
-    "metadata": {
-        "local": ["/Users/rolandh/code/saml2test/testtool/sp_test/idp.xml"]},
-    "name_form": NAME_FORMAT_URI,
-}
+    # "metadata": {"local": ["../idp2/idp.xml"]},
+    # "metadata": {"local": ["/Users/rolandh/code/so_bridge/idp.xml"]},
+    # "metadata": {"local": ["/Users/rolandh/code/s2sproxy/proxy.xml"]},
+    "metadata": [{
+        'class': 'saml2.mdstore.MetaDataFile',
+        'metadata': [
+            ('/Users/rolandh/code/saml2test/testtool/sp_test/tt/sp_test_metadata.xml',
+             )]}],
+        "name_form": NAME_FORMAT_URI,
+    }
