@@ -1,3 +1,4 @@
+import pytest
 from saml2 import config
 
 from saml2.mdstore import MetadataStore
@@ -38,7 +39,7 @@ METADATACONF = {
 #     mds.imp(METADATACONF["2"])
 #     assert len(mds.keys()) >= 1
 
-
+@pytest.mark.network
 def test_signature_no_cert():
     mds = MetadataStore(ATTRCONV, sec_config,
                         disable_ssl_certificate_validation=True)
